bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 16. Aventiure
___________________________________________________ #### Aventivre wie sivrit #### ermort wart
###### 916 | ### Gventher vnd hagene | di recken vil balt ### lobten mit intruwen | ein pirsen in den walt ### mit ir scharffen geren | si wolden iagen swin ### bern vnd wisende | waz moehte chvners gesin
###### 917 | ### damit reit ovch sifrit | in herlichem site ### maniger hande spise | fvrte man in mite ### zeinem chlaren brvnnen | verlos er sit den lip ### daz het geraten prvnnhilt | des kvnich gvntheres wip
###### 918 | ### do gie der degen chvne | da er crimhilde vant ### do was nv vfgesovmet | sin edel pirsgewant ### sin vnd siner gesellen | si wolden vber rin ### do ne dorfte criemhilde | nimmer leider gesin
###### 919 | ### di sine trivttinne | chvst er an den mvnt ### got laze mich dich vrowe | gesehen noch gesvnt ### vnd mich div dinen ovgen | mit holden magen din ### soltv chvercewilen | ine mach hie heime niht gesin
###### 920 | ### do gedahtes an div maere | si ne torster niht gesagen ### div si da hagenen sagete | do begonde klagen ### div edel chveneginne | daz si ie gewan den lip ### do weinete ane mazze | des herren sifrides wip
###### 921 | ### si sprach zv dem recken | lat iwer iagen sin ### mir trovmte hinat | wi zwei wildiv swin ### iageten veber heide | da wurden blvomen rot ### daz ich so sere weine | des get mir waerliche not
###### 922 | ### ich fverhte harte sere | ettelichen rat ### ob man der deheinem | missedienet hat ### di vns gefvgen chvennen | vientlichen haz ### belibet lieber herre | mit rehten triwen rat ich daz
###### 923 | ### er sprach min trivtinne | ich chvm in chvrcen tagen ### ine weiz hie niht der livte | di mir iht hazzes tragen ### alle dine mage | sint mir gemeine holt ### ovch han ich an den degenen | hie niht anders versolt
###### 924 | ### neina herre sifrit | ia fverht ich dinen val ### mir trovmte hinte leide | wi ob dir ce tal ### vielen zwene berge | ine gesach dich nimmer me ### wil dv von mir scheiden | daz tvt mir an dem hercen we
###### 925 | ### er vmbvie mit handen | daz tvgentriche wip ### mit minnechlichem chvessen | trvt er ir schonen lip ### mit vrlovbe er dannen | shiet in chvrcer stvnt ### si ne gesach in leider | darnach nimmer mer gesvnt
###### 926 | ### do ritten si von dannen | in einen tieffen walt ### dvrch chvrcewile willen | vil manich ritter balt ### volgeten gvnthere | vnd sinen man ### ger vnd giselher | di waren da heime bestan
###### 927 | ### geladen vil der rosse | chom vor in veber den rin ### di den iagetgesellen | brot vnd win ### daz vleihs mit den visschen | vnd manigen andern rat ### den ein chvnich so riche | vil harte pillichen hat
###### 928 | ### si hiezen herbergen | fver den grvnen walt ### gegen des waldes ablovffe | di stolcen ieger balt ### da si da iagen solden | vf einen wert vil breit ### da was ovch chomen sifrit | daz wart dem chvenege geseit
###### 929 | ### von den iagtgesellen | wurden do gar bestan ### div warte in allen enden | do sprach der chvene man ### sifrit der vil starche | wer sol vns in den walt ### wisen nach dem wilde | ir helde chvne vnd balt
###### 930 | ### welle wir vns scheiden | sprach do hagene ### e daz wir beginnen | hie ce iagene ### dabi wir mvegen bechennen | ich vnd di herren min ### wer di besten iegere | an dirre waltreise sin
###### 931 | ### livte vnd gehvende | svln wir teilen gar ### so cher ietslicher | swar er gerne var ### swer danne iage daz beste | des sol er haben danch ### do wart der ieger biten | bi einander niht ce lanch
###### 932 | ### do sprach der herre sifrit | ich han der hvnde rat ### niwan einen bracken | der so genozzen hat ### daz er di verte erchenne | der tiere dvrch den tan ### wir chomen wol ce iegede | sprach der criemhilde man
###### 933 | ### do nam ein alter iegere | einen gvten spverhvnt ### er brahte den herren | in einer chvrcer stvnt ### da si vil tieren fvnden | swaz der von laegere stvnt ### di eriagten di gesellen | als noch gvte ieger tvnt
###### 934 | ### swaz ir der bracke erspranchte | di slvch mit siner hant ### sifrit der vil chvene | der helt von niderlant ### sin ros lieff so sere | daz ir im niht entran ### den lob vor in allen er | an dem iegde gewan
###### 935 | ### er was in allen dingen | biderbe genvch ### tier was daz erste | daz er ce tode slvch ### ein vil starchez halp | mit der sinen hant ### darnach er vil schiere | einen vngefvegen lewen vant
###### 936 | ### do den der bracke erspranchte | den shoz er mit dem bogen ### eine starche strale | het er darin gezogen ### der lev lief nach dem shvzze | wan drier sprvenge lanch ### di sinen iagtgesellen | di sagten sifride danch
###### 937 | ### darnach slvch er shiere | einen wisent vnd einen elch ### starcher vower viere | vnd einen grimmen shaelch ### sin ross in trvch so balde | daz ir im niht entran ### hirzze oder hinden | chvnde im wenich engan
###### 938 | ### einen eber grozen | den vant der spverhvnt ### als er begvnde vliehen | do chom an der stvnt ### des selben geiedes meister | er bestvnt in vf der sla ### daz swin vil zornechlichen | lief an den helt san
###### 939 | ### do slvch in mit dem swerte | der criemhilde man ### ez en het ein ander ieger | so samfte niht getan ### do er in het ervellet | man vie der spverhvnt ### do wart sin iaget daz riche | wol den bvergvnden chvnt
###### 940 | ### do sprachen sine iegere | mvegez mit fvege wesen ### so lat vns her sifrit | der tier ein teil genesen ### ir tvt vns hivte laere | den berch vnd ovch den walt ### des begonde smielen | der degen chvene vnde balt
###### 941 | ### do hortens allenthalben | lvdem vnd doz ### von livte vnd ovch von hvnden | was der schal so groz ### daz in davon antwurte | der berch vnd ovch der tan ### vier vnt zweinzech rvore | di ieger heten verlan
###### 942 | ### do mvsen vil der tiere | vliesen da daz leben ### do wanden si daz fvegen | daz man in solde geben ### den pris vor dem geiede | des chvnde niht geschaehen ### do der starche sifrit | wart cer fiwerstat gesaehen
###### 943 | ### daz iagt was ergangen | vnd ovch niht gar ### di cer fiwerstete wolden | di brahten mit in dar ### vil maniger tier hvete | vnd wildes genvch ### hey waz man des cer chvchen | des chvneges ingesinde trvch
###### 944 | ### do hiez der chvenich chvenden | den iegern vzerchorn ### daz er wold enbizzen | do wart vil lvote ein horn ### zeiner stvnt geblasen | damit in wart erchant ### daz man den fvrsten edele | da cen herbergen vant
###### 945 | ### do sprach ein sifrides iaegere | herre ich han vernomen ### von eines hornes dvzze | daz wir nv svln chomen ### zv den herbergen | antwurten ich des wil ### do wart nach den gesellen | gevraget blasende vil
###### 946 | ### do sprach der herre sifrit | nv rvome ovch wir den tan ### sin ross trvch in ebene | si ilten mit im dan ### si erspranchten mit ir shalle | ein tier vil griwelich ### daz was ein ber wilde | do sprach der degen hinder sich
###### 947 | ### ich wil vns hergesellen | gvter chvercewile wern ### ir svlt den bracken lazen | ia sih ich einen bern ### der sol mit vns hinnen | zen herbergen varn ### ern vliehe danne vil sere | ern chan sich es nimmer bewarn
###### 948 | ### der bracke wart verlazen | der bere spranchte von dan ### do wold in erriten | der criemhilde man ### er chom in ein gewelle | do ne chondes niwet wesen ### daz starche tier do wande | vor dem iaegere genesen
###### 949 | ### do spranch von sinem rosse | der stolze ritter gvt ### er begonde nachlovffen | daz tier was vmbehvt ### ez en chonde im niht entrinnen | do viench er iz cehant ### an aller slahte wunden | der helt ez schiere gebant
###### 950 | ### crazcen vnd bizen | chvnde ez niht den man ### er band ez zvme satele | vf saz der snelle san ### er braht iz an di fiwerstat | dvrch sinen hohen mvt ### ceiner chvrzewile | der recke chvene vnt gvt
###### 951 | ### wi rehte herliche | er cen herbergen reit ### sin ger was vil michel | starch vnde breit ### im hiench ein zier waffen | hin nider an den sporn ### von vil rotem golde | fvrt der herre ein schone horn
###### 952 | ### von bezzerm pirschewaete | gehort ich nie gesagen ### einen rok von swarcem pfellel | den sach man in tragen ### vnd eine hvt von zobele | div riche was genvch ### hey waz er richer porten | an sinem chochaere trvch
###### 953 | ### von einem pantel | was darvber gezogen ### ein hvt dvrch di sveze | ovch fvrt er einen bogen ### den man mit antwerche | mvse ziehen dan ### der in spannen solde | ern het ez selbe getan
###### 954 | ### von einer lvdemes hvte | was allez sin gewant ### von hovbet vnz an daz ende | gestrevt man darvffe vant ### vz der liehten rivhe | vil manich goldes zein ### ce beiden sinen siten | dem chvnem iegermeister schein
###### 955 | ### do fvrt er palmvngen | ein ziere waffen breit ### daz was also scherpfe | daz ez nie vermeit ### swa man ez slvch vf helme | sin ecke waren gvt ### der herliche iaeger | was hohe gemvt
###### 956 | ### sit daz ich iv div maere | gar bescheiden sol ### im was sin edel chocher | vil gvter strale vol ### von gvldinen tvellen | div sahs wol hende breit ### ez mvse vil balde sterben | swaz er damit versneit
###### 957 | ### do reit der ritter edele | vil weidenliche dan ### in sahen dort chvmen her | di gvntheres man ### si lieffen im engegen | vnd enpfiengen im daz march ### do fvrt er bi dem satel | einen bern groz vn starch
###### 958 | ### als er gestvnt von rosse | do lost er im div bant ### von fvoze vnd ovch von mvnde | do erlvote da cehant ### vil groze daz gehvende | swaz des den bern sach ### daz tier ce walde wolde | di livte heten vngemach
###### 959 | ### der ber von dem schalle | dvrch di chvochen geriet ### hey waz er chvchenknehte | von dem fiwer schiet ### vil chezzel wart gerveret | cefveret manich brant ### hey waz man gvter spise | in der asschen ligen vant
###### 960 | ### do sprvngen von dem sedele | di herren vnd ir man ### der ber begonde zvernen | der chvenich der hiez do lan ### allez daz gehvende | daz an den seilen lach ### vnd waeriz wol verendet | si heten vrolichen tach
###### 961 | ### mit bogen vnd mit spiezen | niht langer man daz lie ### do lieffen dar di snellen | da der ber gie ### da was so vil der hvnd | daz da niemen shoz ### von des livtes schalle | daz gebirge allez erdoz
###### 962 | ### der ber begonde vliehen | von den hvnden dan ### im chvnde niht gevolgen | wan criemhilde man ### der erlief in mit dem swerte | ce tode er in do slvch ### hin wider zv dem fiwere | den ber man do sider trvch
###### 963 | ### do sprachen di daz sahen | er waere ein creftech man ### di stolzen iagetgesellen | hiez man cen tisschen gan ### vf einem shoenem anger | saz ir da genvch ### hey waz man richer spise | den edeln iegeren do trvch
###### 964 | ### di schenchen chomen seine | di tragen solden win ### ez en chvnde baz gedienet | den helden nimmer sin ### heten si darvnder | niht so valschen mvt ### so waeren wol di recken | vor allen schanden behvt
###### 965 | ### do sprach der herre sifrit | wunder mich des hat ### sit man vns von den chvchen | git so manigen rat ### warvmb vns di shenchen | bringen niht den win ### man en pflaege baz der iegere | ich en wil niht iagetgeselle sin
###### 966 | ### ich hete wol gedienet | daz man min baz naeme war ### der chvenich von sinem tissche | sprach in valsche dar ### man sol iv gerne bvezen | swes wir gebresten han ### daz ist von hagenen schvlden | er wil vns gern erdversten lan
###### 967 | ### do sprach von tronege hagene | vil lieber herre min ### ich wande daz daz pirsen | hivte solde sin ### da cem spehtsharte | den win den sand ich dar ### sin wir hivte vngetrvnchen | wi wol ich mere daz bewar
###### 968 | ### do sprach der herre sifrit | ir lip der hab vndanch ### man solde mir siben sovme | met vnd lvter tranch ### haben her gefveret | do des niht mohte sin ### do sold man vns gesidelt | haben naher an den rin
###### 969 | ### do sprach von tronege hagene | ir edel ritter balt ### ich weiz hie bi nahen | einen brvnnen chalt ### daz ir niht en zvernet | da svln wir hine gan ### der rat wart manigem degene | ce grozen sorgen getan
###### 970 | ### sifrit den recken | twanch des tvrstes not ### den tissch er deste ziter | rvchen dan gebot ### er wolde fver di berge | zv dem brvnnen gan ### do was der rat mit meine | von den rechen getan
###### 971 | ### div tier hiez man waegen | fveren in daz lant ### div hete verhowen | div sifrides hant ### man iah im grozer eren | swer iz ie gesach ### hagen sine triwe | vil sere an sifriden brach
###### 972 | ### do si wolden dannen | zv den linden breit ### do sprach von tronege hagene | mir ist des vil geseit ### daz niht gevolgen chvenne | der criemhilde man ### swenne er wolde gahen | hey wolde er vns daz sehen lan
###### 973 | ### do sprach von niderlande | der chvene sifrit ### daz mvget ir wol versvchen | welt ir mir lovffen mit ### ce wette zv dem brvnnen | so daz ist getan ### dem sol man iehen dannen | den man sihet gewunnen han
###### 974 | ### nv welle ovch wirz versvchen | sprach hagene der degen ### do sprach der snelle sifrit | so wil ich mich legen ### fvor di iwern fvezze | nider an daz gras ### do er daz gehorte | wi lieb ez gvnthere was
###### 975 | ### do sprach der degen chvene | noch wil ich iv mere sagen ### allez min gewaete | wil ich mit mir tragen ### den ger zv dem schilde | vnd al min pirsgewant ### den chocher zv dem swerte | vil schier er vmb gebant
###### 976 | ### do zvgen si div chleider | von dem libe dan ### in zwein wizzen hemden | sach man si beide stan ### sam zwei wildiv pantel | si lieffen dvrch den chle ### do sach man bi dem brvnnen | den chvenen sifriden e
###### 977 | ### den pris an allen dingen | trvch er vor manigem man ### daz swert daz lost er schiere | den chocher leit er dan ### den starchen ger er leinte | an der linden ast ### bi des brvnnen vluzze | stvnt der herliche gast
###### 978 | ### di sifrides tvgende | waren harte groz ### den schilt er leite nider | al da der brvnne vloz ### swi harte in do dvrste | der helt nine tranch ### e daz der chvenich getrvnche | des sagt er im boesen danch
###### 979 | ### der brvnne der was chvle | lvter vnd gvt ### gvnther sich do neigete | nider zv dem flvt ### als er het getrvnchen | do riht er sih von dan ### alsam het ovch gerne | der chvne sifrit getan
###### 980 | ### do engalt er sine zvehte | den bogen vnt daz swert ### daz trvch allez hagene | von im dannewert ### do sprang er hin wider | da er den ger da vant ### er sach nach einem bilde | an des chvenen gewant
###### 981 | ### da der herre sifrit | ob dem brvnnen tranch ### er shoz in dvrch daz crvece | daz von der wunden spranch ### daz blvt im von dem hercen | vaste an hagenen wat ### so groze missewende | ein helt nimmer mer begat
###### 982 | ### den ger im gein dem hercen | er do stechen lie ### also grimmechlichen | ce flvehten hagen nie ### gelief noch in der werlde | vor deheinem man ### do sich der herre sifrit | der grozen wunden versan
###### 983 | ### der herre tobelichen | von dem brvnnen spranch ### im ragete von dem hercen | ein gerstange lanch ### der fverste wande vinden | bogen oder swert ### so mvese wesen hagen | nach sinem dienste gewert
###### 984 | ### do der sere wunde | des swertes niht en vant ### do ne het et er niht mere | want des shildes rant ### er zvchten von dem brvnnen | do lief er hagenen an ### do ne chvnde im niht entrinnen | des chvnich gvntheres man
###### 985 | ### swi wunt er was cem tode | so crefftechlich er slvch ### daz vz dem schilde | draete genvch ### viel des edelen gesteines | der schilt vil gar cerbrast ### sich hete gerne errochen | der vil herliche gast
###### 986 | ### do was gestrvchet hagene | vor siner hant ce tal ### von des slages creffte | der wert vil lvt erhal ### het er daz swert enhande | so waerez hagenen tot ### so sere zvrnt der wunde | des gie im waerlichen not
###### 987 | ### erblichen was sin varwe | ern chvnde niht gesten ### sines libes sterche | mvse gar cergen ### wand er des todes zeichen | in liehter varwe trvch ### sit wart er beweinet | von schonen vrowen genvch
###### 988 | ### do viel in di blvmen | der criemhilde man ### daz plvt von siner wunden | sach man vil vaste gan ### do begonde er schelten | des gie im groziv not ### di vf in geraten | heten den vngetriwen tot
###### 989 | ### do sprach der verchwunde | ia ir vil boesen zagen ### waz helffent miniv dienest | daz ir mich habt erslagen ### ich was ie getriwe | des ich engolten han ### ir habt an iwern magen | leider vbele getan
###### 990 | ### di sint davon bescholten | swaz ir wirt geborn ### her nach disen ziten | ir habet iwern zorn ### gerochen also sere | an dem libe min ### mit laster ir gescheiden | svlt von gvten rechen sin
###### 991 | ### di ritter alle lieffen | da er erslagen lach ### aez was ir genvgen | ein vrevdeloser tach ### di iht triwe heten | von den wart er gechlaeit ### daz het wol verdienet | der ritter chven vnt gemeit
###### 992 | ### der kvenich von bvrgvnden | chlagte sinen tot ### do sprach der verchwunde | ez ist ane not ### daz der nach schaden weinet | der in hat getan ### der dienet michel schelten | ez waere bezer verlan
###### 993 | ### do sprach der grimme hagene | ia ne weiz ich waz er kleit ### allez hat nv ende | vnser sorge vnt vnser leit ### wir vinden ir vil wenich | di getverren vns bestan ### wol mich deich siner herschaft | ce rate han getan
###### 994 | ### ir mveget ivch lihte rvemen | sprach do sifrit ### het ich an iv erchennet | den mortlichen sit ### ich hete wol behalten | vor iv minen lip ### mich riwet niht so sere | so vrov criemhilt min wip
###### 995 | ### nv mvze got erbarmen | deich ie gewan den svn ### dem man daz itewizen | sol nah den ziten tvn ### daz sine mage iemen | mortliche han erslagen ### moht ich so sprach sifrit | daz sold ich pilliche chlagen
###### 996 | ### do sprach iemerliche | der verchwunde man ### welt ir chvenich edele | triwen iht began ### in der werlt iemen | lat iv bevolhen sin ### vf iwer genade | di holden trivtinne min
###### 997 | ### vnd lat si des geniezen | daz si iwer swester si ### dvrch aller fvrsten tvgende | wont ir mit triwen bi ### mir mvezen warten lange | min vater vnd mine man ### ez en wart nie vrowen leider | an liebem manne getan
###### 998 | ### di blvmen allenthalben | von blvte wurden naz ### do rang er mit dem tode | vnlange tet er daz ### want des todes waffen | ie ce sere sneit ### do ne moht niht reden mere | der recke chven vnt gemeit
###### 999 | ### do di herren sahen | daz der helt was tot ### si leiten in vf einen schilt | der was von golde rot ### vnd wurden des ce rate | wi daz sold ergan ### daz man ez verhaele | daz ez hete hagen getan
###### 1000 | ### do sprach ir genvge | vns ist vbel geschehen ### ir svlt ez heln alle | vnt svlt geliche iehen ### da er rite eine iagen | der criemhilde man ### in slvegen schachaere | da er fvere dvrch den tan
###### 1001 | ### do sprach von tronege hagene | ich bringn in daz lant ### mir ist vil vnmaere | vnd wirt ez ir bechant ### div so hat betrvebet | den prvennhilde mvt ### ez ahtet mich vil ringe | swaz si weinens getvt

<<< Übersicht <<< vorige Seite nächste Seite >>>